@@ -44,6 +44,11 @@ metagen <- function(TE, seTE,
   TE   <- mf$TE
   seTE <- mf$seTE
   ##
+  if (!missing(byvar)){
+    byvar.name <- deparse(substitute(byvar))
+    byvar <- mf$byvar
+  }
+  ##
   if (!missing(studlab))
     studlab <- as.character(mf$studlab)
   else
@@ -172,8 +177,10 @@ metagen <- function(TE, seTE,
               label.c=label.c,
               call=match.call())
   ##
-  if (!missing(byvar)) res$byvar <- byvar
-  if (!missing(bylab)) res$bylab <- bylab
+  if (!missing(byvar)){
+    res$byvar <- byvar
+    res$bylab <- if (!missing(bylab)) bylab else byvar.name
+  }
   res$print.byvar <- print.byvar
   
   class(res) <- c("metagen", "meta")
